Compute nearest-neighbor mapping from query ranges to subject ranges.
Usage
fast_distance_to_nearest(
query,
subject,
ignore_strand = FALSE,
threads = fast_default_threads()
)Value
A S4Vectors::DataFrame with query_id, subject_id, and
distance columns.
Details
This function currently returns the same object shape as fast_nearest().
It is provided so users can choose the more explicit name when they care
about the distance column.