Compute per-position coverage for input ranges.
Usage
fast_coverage(
x,
shift = 0L,
width = NULL,
weight = 1L,
method = c("auto", "sort", "hash"),
threads = fast_default_threads()
)Arguments
- x
An
IRangesorGRangesobject.- shift
Passed to
coverage(). Use this to shift intervals before computing coverage.- width
Passed to
coverage(). Use this to force the output length.- weight
Passed to
coverage(). This can be a scalar or vector and is useful when intervals should contribute weighted counts instead of1.- method
Coverage method.
- threads
Integer scalar thread count. Reserved for API consistency.