Return the index of the first subject range that is strictly before each query range.
Usage
fast_follow(
query,
subject,
ignore_strand = FALSE,
threads = fast_default_threads()
)Return the index of the first subject range that is strictly before each query range.
fast_follow(
query,
subject,
ignore_strand = FALSE,
threads = fast_default_threads()
)