Compute nearest-neighbor mapping from query ranges to subject ranges.
Usage
fast_nearest(
query,
subject,
ignore_strand = FALSE,
threads = fast_default_threads()
)Value
A S4Vectors::DataFrame with query_id, subject_id, and
distance columns.
Details
These functions answer nearest-neighbor questions rather than overlap questions.
fast_nearest() and fast_distance_to_nearest() return one row per matched
query.
query_id is the row index in query.
subject_id is the row index of the nearest subject.
distance is 0 when the query overlaps the subject and positive when the
nearest subject is separated by a gap.