Return the index of the first subject range that is strictly after each query range.
Usage
fast_precede(
query,
subject,
ignore_strand = FALSE,
threads = fast_default_threads()
)Return the index of the first subject range that is strictly after each query range.
fast_precede(
query,
subject,
ignore_strand = FALSE,
threads = fast_default_threads()
)